@@ -461,55 +461,68 @@ JAGS_add_priors           <- function(syntax, prior_list){
     stop("improper prior provided")
   check_char(parameter_name, "parameter_name")
 
-  # create the location/means vector the sigma matrix
-  par1 <- switch(
-    prior[["distribution"]],
-    "mnormal" = prior$parameter[["mean"]],
-    "mt"      = prior$parameter[["location"]]
-  )
-  par2 <- switch(
-    prior[["distribution"]],
-    "mnormal" = prior$parameter[["sd"]],
-    "mt"      = prior$parameter[["scale"]]
-  )
 
-  # TODO: beautify this code by specific JAGS distributions?
-  if(prior[["distribution"]] == "mt"){
-    # using the chisq * covariance parametrization since the mt fails with 1 df
-    # (using a common df parameter as in Rouder et al. 2012)
-    syntax <- paste0("prior_par1_", parameter_name, " = rep(0,", prior$parameter[["K"]], ")\n")
-    syntax <- paste0(syntax, "prior_par_s_", parameter_name, " ~ dgamma(", prior$parameter[["df"]]/2, ", ", prior$parameter[["df"]]/2,")\n")
+  if(prior[["distribution"]] %in% c("mnormal", "mt")){
+    # create the location/means vector the sigma matrix
+
+    par1 <- switch(
+      prior[["distribution"]],
+      "mnormal" = prior$parameter[["mean"]],
+      "mt"      = prior$parameter[["location"]]
+    )
+    par2 <- switch(
+      prior[["distribution"]],
+      "mnormal" = prior$parameter[["sd"]],
+      "mt"      = prior$parameter[["scale"]]
+    )
+
+    # TODO: beautify this code by specific JAGS distributions?
+    if(prior[["distribution"]] == "mt"){
+      # using the chisq * covariance parametrization since the mt fails with 1 df
+      # (using a common df parameter as in Rouder et al. 2012)
+      syntax <- paste0("prior_par1_", parameter_name, " = rep(0,", prior$parameter[["K"]], ")\n")
+      syntax <- paste0(syntax, "prior_par_s_", parameter_name, " ~ dgamma(", prior$parameter[["df"]]/2, ", ", prior$parameter[["df"]]/2,")\n")
+      syntax <- paste0(
+        syntax,
+        "for(i in 1:", prior$parameters[["K"]], "){\n",
+        "  prior_par2_", parameter_name, "[i,i] <- ", 1/par2^2, "\n",
+        "  for(j in 1:(i-1)){\n",
+        "    prior_par2_", parameter_name, "[i,j] <- 0\n",
+        "  }\n",
+        "  for (j in (i+1):", prior$parameters[["K"]], "){\n",
+        "    prior_par2_", parameter_name, "[i,j] <- 0\n",
+        "  }\n",
+        "}\n",
+        "prior_par_z_", parameter_name, " ~ dmnorm(prior_par1_", parameter_name, ",prior_par2_", parameter_name, ")\n",
+        "for(i in 1:", prior$parameters[["K"]], "){\n",
+        "  ", parameter_name, "[i] <- prior_par_z_", parameter_name, "[i]/sqrt(prior_par_s_", parameter_name, ") + ", par1, " \n",
+        "}\n")
+    }else if(prior[["distribution"]] == "mnormal"){
+      syntax <- paste0("prior_par1_", parameter_name, " = rep(", par1, ",", prior$parameter[["K"]], ")\n")
+      syntax <- paste0(
+        syntax,
+        "for(i in 1:", prior$parameters[["K"]], "){\n",
+        "  prior_par2_", parameter_name, "[i,i] <- ", 1/par2^2, "\n",
+        "  for(j in 1:(i-1)){\n",
+        "    prior_par2_", parameter_name, "[i,j] <- 0\n",
+        "  }\n",
+        "  for (j in (i+1):", prior$parameters[["K"]], "){\n",
+        "    prior_par2_", parameter_name, "[i,j] <- 0\n",
+        "  }\n",
+        "}\n")
+      syntax <- paste0(syntax, parameter_name," ~ dmnorm(prior_par1_", parameter_name, ",prior_par2_", parameter_name, ")\n")
+    }
+
+  }else if(prior[["distribution"]] == "mpoint"){
+
     syntax <- paste0(
-      syntax,
       "for(i in 1:", prior$parameters[["K"]], "){\n",
-      "  prior_par2_", parameter_name, "[i,i] <- ", 1/par2^2, "\n",
-      "  for(j in 1:(i-1)){\n",
-      "    prior_par2_", parameter_name, "[i,j] <- 0\n",
-      "  }\n",
-      "  for (j in (i+1):", prior$parameters[["K"]], "){\n",
-      "    prior_par2_", parameter_name, "[i,j] <- 0\n",
-      "  }\n",
-      "}\n",
-      "prior_par_z_", parameter_name, " ~ dmnorm(prior_par1_", parameter_name, ",prior_par2_", parameter_name, ")\n",
-      "for(i in 1:", prior$parameters[["K"]], "){\n",
-      "  ", parameter_name, "[i] <- prior_par_z_", parameter_name, "[i]/sqrt(prior_par_s_", parameter_name, ") + ", par1, " \n",
+      "  ", parameter_name, "[i] = ", prior$parameter[["location"]], " \n",
       "}\n")
-  }else{
-    syntax <- paste0("prior_par1_", parameter_name, " = rep(", par1, ",", prior$parameter[["K"]], ")\n")
-    syntax <- paste0(
-      syntax,
-      "for(i in 1:", prior$parameters[["K"]], "){\n",
-      "  prior_par2_", parameter_name, "[i,i] <- ", 1/par2^2, "\n",
-      "  for(j in 1:(i-1)){\n",
-      "    prior_par2_", parameter_name, "[i,j] <- 0\n",
-      "  }\n",
-      "  for (j in (i+1):", prior$parameters[["K"]], "){\n",
-      "    prior_par2_", parameter_name, "[i,j] <- 0\n",
-      "  }\n",
-      "}\n")
-    syntax <- paste0(syntax, parameter_name," ~ dmnorm(prior_par1_", parameter_name, ",prior_par2_", parameter_name, ")\n")
+
   }
 
+
   return(syntax)
 }
 .JAGS_prior.factor         <- function(prior, parameter_name){
@@ -518,18 +531,18 @@ JAGS_add_priors           <- function(syntax, prior_list){
   if(!is.prior.factor(prior))
     stop("improper prior provided")
   check_char(parameter_name, "parameter_name")
-  check_int(attr(prior, "levels"), "levels", lower = 2)
+  check_int(.get_prior_factor_levels(prior), "levels", lower = 1)
 
-  if(is.prior.point(prior) | is.prior.dummy(prior)){
+  if(is.prior.treatment(prior) | is.prior.independent(prior)){
 
     syntax <- paste0(
-      "for(i in 1:", attr(prior, "levels") - 1, "){\n",
+      "for(i in 1:", .get_prior_factor_levels(prior), "){\n",
       "  ", .JAGS_prior.simple(prior, paste0(parameter_name, "[i]")),
       "}\n")
 
-  }else if(is.prior.orthonormal(prior)){
+  }else if(is.prior.orthonormal(prior) | is.prior.meandif(prior)){
 
-    prior$parameters[["K"]] <- attr(prior, "levels") - 1
+    prior$parameters[["K"]] <- .get_prior_factor_levels(prior)
 
     syntax <- .JAGS_prior.vector(prior, parameter_name)
 
@@ -791,19 +804,19 @@ JAGS_get_inits            <- function(prior_list, chains, seed){
   if(!is.prior.factor(prior))
     stop("improper prior provided")
   check_char(parameter_name, "parameter_name")
-  check_int(attr(prior, "levels"), "levels", lower = 2)
+  check_int(.get_prior_factor_levels(prior), "levels", lower = 1)
 
-  if(is.prior.point(prior) | is.prior.dummy(prior)){
+  if(is.prior.treatment(prior) | is.prior.independent(prior)){
 
     init <- list()
-    init[[parameter_name]] <- rng(prior, attr(prior, "levels") - 1)
+    init[[parameter_name]] <- rng(prior, .get_prior_factor_levels(prior))
 
-  }else if(is.prior.orthonormal(prior)){
+  }else if(is.prior.orthonormal(prior) | is.prior.meandif(prior)){
 
-    prior$parameters[["K"]] <- attr(prior, "levels") - 1
+    prior$parameters[["K"]] <- .get_prior_factor_levels(prior)
 
-    # remove the orthonormal class, otherwise samples from the transformed distributions are generated
-    class(prior) <- class(prior)[!class(prior) %in% "prior.orthonormal"]
+    # remove the orthonormal/meandif class, otherwise samples from the transformed distributions are generated
+    class(prior) <- class(prior)[!class(prior) %in% c("prior.orthonormal", "prior.meandif")]
 
     init <- .JAGS_init.vector(prior, parameter_name)
 
